@@ -9,10 +9,10 @@ import sys
 from zope.interface import implementer
 
 from pyramid.interfaces import IAuthenticationPolicy, PHASE2_CONFIG
-from pyramid.security import Everyone, Authenticated
+from pyramid.authorization import Everyone, Authenticated
 
 __ver_major__ = 0
-__ver_minor__ = 4
+__ver_minor__ = 9
 __ver_patch__ = 0
 __ver_sub__ = ""
 __ver_tuple__ = (__ver_major__, __ver_minor__, __ver_patch__, __ver_sub__)
@@ -37,10 +37,11 @@ class MultiAuthPolicySelected(object):
             print("We selected policy %s" % event.policy)
 
     """
-    def __init__(self, policy, request):
+    def __init__(self, policy, request, userid=None):
         self.policy = policy
         self.policy_name = getattr(policy, "_pyramid_multiauth_name", None)
         self.request = request
+        self.userid = userid
 
 
 @implementer(IAuthenticationPolicy)
@@ -77,7 +78,8 @@ class MultiAuthenticationPolicy(object):
             userid = policy.authenticated_userid(request)
             if userid is not None:
                 request.registry.notify(MultiAuthPolicySelected(policy,
-                                                                request))
+                                                                request,
+                                                                userid))
 
                 if self._callback is None:
                     break
@@ -117,6 +119,9 @@ class MultiAuthenticationPolicy(object):
                 userid = policy.authenticated_userid(request)
                 if userid is None:
                     continue
+                request.registry.notify(MultiAuthPolicySelected(policy,
+                                                                request,
+                                                                userid))
                 groups = self._callback(userid, request)
                 if groups is not None:
                     break
@@ -129,7 +134,7 @@ class MultiAuthenticationPolicy(object):
     def remember(self, request, principal, **kw):
         """Remember the authenticated userid.
 
-        This method returns the concatentation of the headers returned by each
+        This method returns the concatenation of the headers returned by each
         authn policy.
         """
         headers = []
@@ -140,7 +145,7 @@ class MultiAuthenticationPolicy(object):
     def forget(self, request):
         """Forget a previusly remembered userid.
 
-        This method returns the concatentation of the headers returned by each
+        This method returns the concatenation of the headers returned by each
         authn policy.
         """
         headers = []
