@@ -2,23 +2,17 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this file,
 # You can obtain one at http://mozilla.org/MPL/2.0/.
 
-import sys
+import unittest
 from zope.interface import implementer
 
-import pyramid.authorization
 import pyramid.testing
 from pyramid.testing import DummyRequest
-from pyramid.security import Everyone, Authenticated
+from pyramid.authorization import ACLAuthorizationPolicy, Authenticated, Everyone
 from pyramid.exceptions import Forbidden
 from pyramid.interfaces import IAuthenticationPolicy, IAuthorizationPolicy
 
 from pyramid_multiauth import MultiAuthenticationPolicy
 
-if sys.version_info < (2, 7):
-    import unittest2 as unittest  # pragma: nocover
-else:
-    import unittest  # pragma: nocover
-
 
 #  Here begins various helper classes and functions for the tests.
 
@@ -198,9 +192,17 @@ class MultiAuthPolicyTests(unittest.TestCase):
 
             self.assertEquals(selected_policy[0].policy, policies[0])
             self.assertEquals(selected_policy[0].policy_name, "name")
+            self.assertEquals(selected_policy[0].userid, "test2")
             self.assertEquals(selected_policy[0].request, request)
             self.assertEquals(len(selected_policy), 1)
 
+            # Effective principals also triggers an event when groupfinder
+            # is provided.
+            policy_with_group = MultiAuthenticationPolicy(policies,
+                                                          lambda u, r: ['foo'])
+            policy_with_group.effective_principals(request)
+            self.assertEquals(len(selected_policy), 2)
+
     def test_stacking_of_unauthenticated_userid(self):
         policies = [TestAuthnPolicy2(), TestAuthnPolicy3()]
         policy = MultiAuthenticationPolicy(policies)
@@ -289,7 +291,7 @@ class MultiAuthPolicyTests(unittest.TestCase):
         self.config.include("pyramid_multiauth")
         self.config.commit()
         policy = self.config.registry.getUtility(IAuthorizationPolicy)
-        expected = pyramid.authorization.ACLAuthorizationPolicy
+        expected = ACLAuthorizationPolicy
         self.assertTrue(isinstance(policy, expected))
 
     def test_includeme_reads_authorization_from_settings(self):
